/*
 * This file is part of Gterm.
 *
 * Gterm is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Foobar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

gboolean show_version (gchar *, gchar *, gpointer, GError **);
gboolean set_font (gchar *, gchar *, gpointer, GError **);
gboolean set_cmd (gchar *, gchar *, gpointer, GError **);
gboolean set_scroll (gchar *, gchar *, gpointer, GError **);
gboolean set_color (gchar *, gchar *, gpointer, GError **);
gboolean set_cfg (gchar *, gchar *, gpointer, GError **);

void add_env (gpointer, gpointer, gpointer);

void window_set_title (GtkWidget *, gpointer);

void drop_data (GtkWidget *, GdkDragContext *, gint, gint,
                GtkSelectionData *, guint, guint, gpointer);

#ifdef USE_MENU
gboolean popup_menu (GtkWidget *, GdkEventButton *, gpointer);
#endif
